<?php 

namespace Management\Services;

use Doctrine\ORM\EntityManager;
use Management\Util;

class ManageDashboardService {
	
	const NOME_TODAS_UNIDADES = 'Todas Unidades';
	const MAX_DIAS_ANTERIORES = 20;
	const MAX_FILTRO = 30;
	
	private $filialoperador;
	
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
	
	public function getIdUtlPerfilFilial($NRORG) {
        $params = array(
            ':NRORG' => $NRORG
        );
        $query = "SELECT IDUTLPERFILFILIAL FROM PARAMGERAL WHERE NRORG =:NRORG";
        $result = $this->entityManager->getConnection()->fetchAssoc($query, $params);

        return $result["IDUTLPERFILFILIAL"];
    }
	
	public function getVendasMensais($CDFILIAL,$NRORG) {
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':NRORG' => $NRORG		
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_MENSAIS, $params);
	}
	
	public function getObjetivoVendaDiaAlt($CDFILIAL,$NRORG,$CDOBJANO,$NRDIASEMANA,$DTALT,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':NRDIASEMANA'	=>	$NRDIASEMANA,
			':DTALT'		=>	$DTALT,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA_ALT, $params);
	}
	
	public function getObjetivoVendaDia($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJDIA,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJDIA'		=>	$CDOBJDIA,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA, $params);
	}
	
	public function getObjetivoVendaMes($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_MES, $params);
	}
	
	public function getVendasDiarias($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		
		$vndsConc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CONCLUIDAS, $params);
		$vndsCanc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CANCELADAS, $params);
	
		return array_merge($vndsConc[0], $vndsCanc[0]);
	}
	
	public function getProdutosMaisVendidos($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_PRODUTOS_MAIS_VENDIDOS, $params);
	}
	
	public function findDivergenciasConciliacao ($NRORG) {
		$params = array (
			':NRORG'	=> $NRORG
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::COUNT_DIVERGENCIAS_CONCILIACO, $params);
	}
	
	public function findFiliaisDoOperador ($CDOPERADOR, $NRORG) {
		$params = array (
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FILIAIS_OPERADOR, $params);
	}
	
	public function findConsolidacaoVendaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':TODASNF'   => 'S'
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCupomPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCaixaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function unidadeBloq($conditions){
		$params = array(
        		":NRORG"    	  => $conditions["NRORG"],
        		":CDFILIAL"		  => $conditions["CDFILIAL"],
        		":CDOPERADOR"     => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_IS_FILIAL_BLOQ, $params);
		
	}
	
	public function perfilUtlBloq ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":NRPERFILACESSO"		  => $conditions["CDPERFILSELECIONADO"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::PERF_UTL_BLOQ, $params)['IDBLOCKFILIAL'] == 'N';
		
	}
	
	public function paramOperador ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":CDOPERADOR"		  => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_PARAM_OPERADOR, $params);
		
	}
	
	public function paramPerfilSelecionado($nrorg, $cdoperador){
		$params = array(
        		":NRORG"    			      => $nrorg,
        		":CDOPERADOR"		  => $cdoperador
        	);
        return $this->entityManager->getConnection()->fetchAssoc(self::GET_PERFIL_OPERADOR, $params);
	}
	
	public function findGetTypeDash(){
        return $this->entityManager->getConnection()->fetchAssoc(self::GET_TYPE_DASHBOARD);
	}
	
	public function findGetFilial($CDFILIAL){
		$params = array(
    		":CDFILIAL"		  => $CDFILIAL
    	);
    	
        $filial = $this->entityManager->getConnection()->fetchAssoc(self::GET_FILIAL, $params);
        
        return $filial['FILIAL'];
	}
	
	
	/*DASHBOARD 3*/
	
	public function findV_QTTICKET($condition) {
		
		$arrayCards = ['QTTICKETCARD', 'salesConcluded'];
		
		$retornoCards = null; 
		/*$QTNFEPEND = null;
		$QTNFEDIGIT = null;
		$QTNFSPEND = null;
		$QTNFSDIGIT = null;
		$QTNFEIMPORTXML = null;
		$QTNFEDIGITHAND = null;
		*/
		
		$params = array (
			':NRORG'	=> $condition['NRORG'],
			':CDFILIAL'	=> $condition['CDFILIAL'],
			':DTVNDCARDS'	=> $condition['DTVNDCARDS'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':CDOPERADOR'	=> $condition['CDOPERADOR']
		);
		
		// IF QUE TRAZ TODAS UNIDADES DO OPERADOR LOGADO
		$result = $this->entityManager->getConnection()->fetchAssoc(self::GET_V_QTTICKET, $params);
		
		
		/*$QTNFEPEND = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_PEND, $params)[0];
		$QTNFEDIGIT = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_DIGIT, $params)[0];
		$QTNFSPEND = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_PEND, $params)[0];
		$QTNFSDIGIT = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_DIGIT, $params)[0];
		$QTNFSDIGITHAND = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_DIGIT_HAND, $params)[0];
		$QTNFEIMPORTXML = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_IMPORT_XML, $params)[0];
		$QTNFEDIGITHAND = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_DIGIT_HAND, $params)[0];
		$VENCIMENTO["VENCIMENTO"] = 'V';
		if (strlen($CDFILIAL) < 7 && $TCDFILIAL <> 'T') {
			$valid = $this->entityManager->getConnection()->fetchAll(self::GET_VALID_CERTIFICADO, $params);
			if (is_numeric(array_search('FNC', array_column($valid, 'EMISSAO')))) {
				$VENCIMENTO = $this->entityManager->getConnection()->fetchAll(self::GET_VENCIMENTO_CERTIFICADO, $params)[0];
			}
			if($VENCIMENTO["VENCIMENTO"] == null){
				$VENCIMENTO["VENCIMENTO"] = 'SC';
			}
			else if($VENCIMENTO["VENCIMENTO"] > '90'){
				$VENCIMENTO["VENCIMENTO"] = 'V';
			}
		}
		
		$result[0]["QTNFEPEND"] = (float)$QTNFEPEND['QTNFEPEND'];
		$result[0]["QTNFEDIGIT"] = (float)$QTNFEDIGIT['QTNFEDIGIT'];
		$result[0]["QTNFSPEND"] = (float)$QTNFSPEND['QTNFSPEND'];
		$result[0]["QTNFSDIGIT"] = (float)$QTNFSDIGIT['QTNFSDIGIT'];
		$result[0]["QTNFEIMPORTXML"] = (float)$QTNFEIMPORTXML['QTNFEIMPORTXML'];
		$result[0]["QTNFEDIGITHAND"] = (float)$QTNFEDIGITHAND['QTNFEDIGITHAND'];
		$result[0]["QTNFSDIGITHAND"] = (float)$QTNFSDIGITHAND['QTNFSDIGITHAND'];
		$result[0]["VENCIMENTO"] = $VENCIMENTO['VENCIMENTO'];
		foreach ($result as &$values) {
        	$values['QTTICKETCARD'] 	= empty($values['QTTICKETCARD']) ? 0.00 : (float)$values['QTTICKETCARD'];
        	$values['TOTVENDCARD']		= empty($values['TOTVENDCARD']) ? 0.00 : (float)$values['TOTVENDCARD'];
        	$values['CANCVENDCARD'] 	= empty($values['CANCVENDCARD']) ? 0.00 : (float)$values['CANCVENDCARD'];
        	$values['FECHCAIXPENDCARD'] = empty($values['FECHCAIXPENDCARD']) ? 0.00 : (float)$values['FECHCAIXPENDCARD'];
        	$values['APROVMOVCARD'] 	= empty($values['APROVMOVCARD']) ? 0.00 : (float)$values['APROVMOVCARD'];
        	$values['DIFAPURACARD'] 	= empty($values['DIFAPURACARD']) ? 0.00 : (float)$values['DIFAPURACARD'];
        	$values['QTDIFAPURACARD']	= empty($values['QTDIFAPURACARD']) ? 0.00 : (float)$values['QTDIFAPURACARD'];
        	$values['CUPOMPENDCARD']	= empty($values['CUPOMPENDCARD']) ? 0.00 : (float)$values['CUPOMPENDCARD'];
        	$values['ITESTPENDCARD']	= empty($values['ITESTPENDCARD']) ? 0.00 : (float)$values['ITESTPENDCARD'];
        	$values['AVGTICKETCARD']	= empty($values['AVGTICKETCARD']) ? 0.00 : (float)$values['AVGTICKETCARD'];
        	$values['PRODIRREG']		= empty($values['PRODIRREG']) ? 0.00 : (float)$values['PRODIRREG'];
        }
        */
        
    	/*foreach ($result as $key => $values) {
        	$retornoCards[$key]['visible'] = true;
        	$retornoCards[$key]['name'] = $key;
        	$retornoCards[$key]['value'] = empty($result[$key]) ? 0.00 : (float)$result[$key]; 
        }*/
        
    	foreach ($arrayCards as $key => $values) {
        	$retornoCards[$key]['visible'] = true;
        	$retornoCards[$key]['name'] = $values;
        	$retornoCards[$key]['value'] = empty($result[$values]) ? 0.00 : (float)$result[$values]; 
        }	
        
		return $retornoCards;
	}
	
	private function getVQTTICKET($params){
		
		$query = "SELECT SUM(NVL(V.QTTICKETCARD, 0 )) QTTICKETCARD, SUM( NVL(V.TOTVENDCARD, 0 ) ) TOTVENDCARD,
			   SUM( NVL(V.CANCVENDCARD, 0 ) ) CANCVENDCARD, SUM( NVL(V.FECHCAIXPENDCARD, 0 ) ) FECHCAIXPENDCARD,
				SUM( NVL(V.APROVMOVCARD, 0 ) ) APROVMOVCARD, SUM( NVL(V.DIFAPURACARD, 0 ) ) DIFAPURACARD,
				SUM( NVL(V.QTDIFAPURACARD, 0 ) ) QTDIFAPURACARD, SUM( NVL(V.CUPOMPENDCARD, 0 ) ) CUPOMPENDCARD,
				SUM( NVL(V.ITESTPENDCARD, 0 ) ) ITESTPENDCARD, SUM( NVL(V.AVGTICKETCARD, 0)  )AVGTICKETCARD,
				SUM( NVL(V.PRODIRREG, 0)  ) PRODIRREG
		  FROM VNDCARDS V
		  JOIN (".$this->filialoperador.") F
		    ON V.CDFILIAL = F.CDFILIAL
		 WHERE V.NRORG = :NRORG 
           AND V.DTVNDCARDS = :DTVNDCARDS ";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFEPEND($params){
		
		$query = "SELECT COUNT(*) QTNFEPEND
		  FROM NOTAFISCAL N
		  JOIN  (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFEDIGIT($params){
		
		$query = "SELECT COUNT(*) QTNFEDIGIT
		  FROM NOTAFISCAL N
		  JOIN  (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFEDIGITHAND($params){
		
		$query = "SELECT COUNT(*) QTNFEDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN  (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'N'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFEIMPORTXML($params){
		
		$query = "SELECT COUNT(*) QTNFEIMPORTXML
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'S'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFSDIGIT($params){
		
		$query = "SELECT COUNT(*) QTNFSDIGIT
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFSPEND($params){
		
		$query = "SELECT COUNT(*) QTNFSPEND
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	private function getNFSDIGITHAND($params){
		
		$query = "SELECT COUNT(*) QTNFSDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	public function findCardsCorp($condition) {
		
		$params = array (
			':NRORG'	=> $condition['NRORG'],
			':CDFILIAL'	=> $condition['CDFILIAL'],
			':DTVNDCARDS'	=> $condition['DTVNDCARDS'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$resultVNDCARDS = $this->getVQTTICKET($params);
		
		//formatValoresZerados
		$resultVNDCARDS = $this->setZeroRetornoVazio($resultVNDCARDS);
		
		// NF De Entrada Pendentes
		$QTNFEPEND = $this->getNFEPEND($params);
		
		// NF De Entrada Em Digitação
		$QTNFEDIGIT = $this->getNFEDIGIT($params);
    	
    	//NF De Entrada Digitadas
    	$QTNFEDIGITHAND = $this->getNFEDIGITHAND($params);
    	
    	//NF De Entrada Importadas (XML)
    	$QTNFEIMPORTXML = $this->getNFEIMPORTXML($params);
    	
    	//NF De Saida Em Digitação
    	$QTNFSDIGIT =  $this->getNFSDIGIT($params);
    	
    	//NF De Saida Pendentes
    	$QTNFSPEND = $this->getNFSPEND($params);
    	
    	//NF De Saida Digitadas
    	$QTNFSDIGITHAND = $this->getNFSDIGITHAND($params);
    	
    	//Dias para o vencimento do certificado digital
    	$VENCIMENTO["VENCIMENTO"] = 'V';
    	
    	if(strlen($params[':CDFILIAL']) < 7 && $params[':TCDFILIAL'] <> 'T'){
    		$valid = $this->entityManager->getConnection()->fetchAll(self::GET_VALID_CERTIFICADO, $params);
			if (is_numeric(array_search('FNC', array_column($valid, 'EMISSAO')))) {
				$VENCIMENTO = $this->entityManager->getConnection()->fetchAssoc(self::GET_VENCIMENTO_CERTIFICADO, $params);
			}
			
			if($VENCIMENTO["VENCIMENTO"] == null){
				$VENCIMENTO["VENCIMENTO"] = 'SC';
			}
			else if($VENCIMENTO["VENCIMENTO"] > '90'){
				$VENCIMENTO["VENCIMENTO"] = 'V';
			}
    	}
    	
    	$result = array_merge($resultVNDCARDS, $QTNFEPEND, $QTNFEDIGIT, $QTNFEDIGITHAND, $QTNFEIMPORTXML, $QTNFSDIGIT, $QTNFSPEND, $QTNFSDIGITHAND, $VENCIMENTO);
		
		return $result;
	}
	
	private function setZeroRetornoVazio($result){
		
    	foreach ($result as $key => $values) {
        	$result[$key] = empty($result[$key]) ? 0 : $result[$key]; 
        }
    
		return $result;
	}
	
	private function formatRetorno($result){
		
    	foreach ($result as $key => $values) {
        	$result[$key] = empty($result[$key]) ? 0.00 : (float)$result[$key]; 
        }
    
		return $result;
	}
	
	private function setFiliOper($condition, $params = []){

        unset($params[':CDFILIAL']);

        $CDFILIAL = preg_replace('/(^_+|_+$)/', '', $condition['CDFILIAL']);
        $CDFILIAL = preg_replace('/_+/', "', '", $CDFILIAL);
        $CDFILIAL = "'" . $CDFILIAL . "'";
        
		
		if($condition['PERFACESSFILI'] == 'S'){
			$this->filialoperador = "SELECT T.* FROM (SELECT F.CDFILIAL
            FROM FILIAL F
            JOIN PERFACESSFILI FO ON F.CDFILIAL = FO.CDFILIAL		
            WHERE FO.CDOPERADOR = :CDOPERADOR
              AND F.NRORG = :NRORG		  
              AND (INSTR(
                           (SELECT CASE IDBLOCKFILIAL
                                       WHEN 'S' THEN 'N'
                                       WHEN 'N' THEN 'S_N'
                                   END AS IDSTATUSBLOQ
                            FROM PERFILACESSO
                            WHERE NRPERFILACESSO = :PERFIL ), F.IDSTATUSBLOQ) <> 0)
              AND FO.NRPERFILACESSO = :PERFIL
              AND (FO.DTVALIDADE IS NULL OR (TRUNC(FO.DTVALIDADE) >= TRUNC(SYSDATE)))) T 
              WHERE ((T.CDFILIAL IN (".$CDFILIAL.")) OR (:TCDFILIAL = 'T'))";
		} else{
			$this->filialoperador = "SELECT DISTINCT (CDFILIAL) AS CDFILIAL
		     FROM FILIOPER
		    WHERE CDOPERADOR = :CDOPERADOR
		      AND (CDFILIAL IN (".$CDFILIAL.") OR (:TCDFILIAL = 'T'))";
		}
		
	}
	
	public function findCardsPadrao($condition){
		
		$params = array (
			':NRORG'	=> $condition['NRORG'],
			':CDFILIAL'	=> $condition['CDFILIAL'],
			':DTVNDCARDS'	=> $condition['DTVNDCARDS'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$vendasConcluidas = $this->getQuantidadeVendasConcluidasByFilial($params);
		$vendasCanceladas = $this->getQuantidadeVendasCanceladasByFilial($params);
		
		//pega card de Fechamento de Cupom Pendente 
		$resultFCupom = $this->getFechamentoCupomPendente($params);
		
		//pega card de Consolidacao Pendentes
		$resultConsoPend = $this->getConsolidacaoVendaPendente($params);
		
		//pega card de Fechamento Caixa Pendente
		$resultCaixaPend = $this->getFechamentoCaixaPendente($params);
		
		//pega card de Inconsistencias de Integracao
		$resultInconsIntegracao = $this->entityManager->getConnection()->fetchAssoc(self::COUNT_DIVERGENCIAS_CONCILIACO, $params);
		
		$result = array_merge($vendasConcluidas, $vendasCanceladas, $resultFCupom, $resultConsoPend, $resultCaixaPend, $resultInconsIntegracao);
		
		return $result;
		
	}
	
	
	//gets cards padrao

	public function getQuantidadeVendasConcluidasByFilial ($params) {
		
		$query = "SELECT NVL(SUM(NVL(NRVENDACON, 0)), 0) AS SALESCONCLUDED
		FROM VENDADIATOTAL
		WHERE TRUNC(DTVENDA) = TO_DATE(:DTVNDCARDS, 'dd/mm/yy')
		AND CDFILIAL IN
		  (".$this->filialoperador.")
        	  AND NRORG = :NRORG";
        	  
	   return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}

	public function getQuantidadeVendasCanceladasByFilial ($params) {
		
		$query = "SELECT NVL(SUM(NVL(NRVENDACAN, 0)), 0) AS SALESCANCELED
		FROM VENDADIATOTAL
		WHERE TRUNC(DTVENDA) = TO_DATE(:DTVNDCARDS, 'dd/mm/yy')
		AND CDFILIAL IN
		  (".$this->filialoperador.")
		AND NRORG = :NRORG";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	public function getFechamentoCupomPendente ($params) {
		
		$query = "SELECT COUNT(*) AS FECHCUPOMPEND FROM
         (SELECT CASE RZ.IDSTATUS
                        WHEN 'P' THEN 'Pendente'
                        WHEN 'E' THEN 'Com Erro'
                        WHEN 'A' THEN 'Aprovada'
                        ELSE RZ.IDSTATUS
                     END AS IDSTATUS, RZ.CDFILIAL, RZ.CDCAIXA, 
                     RZ.IDORIGEMREDZ, RZ.NRORG, RZ.DTREDUCAOZ AS DTREDUCAOZ
              FROM REDUCAOZ RZ
              JOIN (SELECT FILIOPERLOJACAIX.CDCAIXA, FILIOPERLOJACAIX.NMCAIXA, FILIOPERLOJACAIX.CDFILIAL, FILIOPERLOJACAIX.CDLOJA, FILIOPERLOJACAIX.NMLOJA, FILIOPERLOJACAIX.NRORG, T.DTFECHCAIX, T.DTMOVTURCAIX
                    FROM TURCAIXA T
                    JOIN (SELECT C.CDCAIXA, C.NMCAIXA, FILIOPERLOJA.CDFILIAL, FILIOPERLOJA.CDLOJA, FILIOPERLOJA.NMLOJA, FILIOPERLOJA.NRORG
                            FROM CAIXA C
                            JOIN (SELECT L.CDLOJA, L.NMLOJA, FILIOPER.CDFILIAL, L.NRORG
                                    FROM LOJA L
                                    JOIN (".$this->filialoperador.")FILIOPER
                                      ON FILIOPER.CDFILIAL = L.CDFILIAL
                                 )FILIOPERLOJA
                              ON FILIOPERLOJA.CDFILIAL = C.CDFILIAL
                             AND FILIOPERLOJA.CDLOJA = C.CDLOJA
                             AND FILIOPERLOJA.NRORG = C.NRORG 
                         )FILIOPERLOJACAIX
                      ON FILIOPERLOJACAIX.CDCAIXA = T.CDCAIXA
                     AND FILIOPERLOJACAIX.CDFILIAL = T.CDFILIAL
                     AND FILIOPERLOJACAIX.NRORG = T.NRORG
                   WHERE T.DTFECHCAIX IS NOT NULL
                     )FILIOPERLOJACAIXTUR
                ON RZ.CDFILIAL = FILIOPERLOJACAIXTUR.CDFILIAL
               AND RZ.CDCAIXA = FILIOPERLOJACAIXTUR.CDCAIXA
               AND RZ.NRORG   = FILIOPERLOJACAIXTUR.NRORG
               AND RZ.DTREDUCAOZ  = FILIOPERLOJACAIXTUR.DTMOVTURCAIX
               WHERE (RZ.DTREDUCAOZ BETWEEN NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY') - 30), SYSDATE-30) AND NVL(TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY'), SYSDATE))
                 AND ( INSTR('P_E', RZ.IDSTATUS) > 0 ) 
                 AND VRVENBRUREDZ <> 0
                 AND VRVENLIQREDZ <> 0
        
              UNION ALL
        
              SELECT DISTINCT CASE V.IDAPROVACAONFCE
                       WHEN 'P' THEN 'Pendente'
                       WHEN 'E' THEN 'Com Erro'
                       WHEN 'A' THEN 'Aprovada'
                       ELSE V.IDAPROVACAONFCE
                     END AS IDSTATUS, V.CDFILIAL, V.CDCAIXA, 
                     DECODE(V.IDTPEMISVEND,'N','NFCE','S','SAT') AS IDORIGEMREDZ, V.NRORG, 
                     V.DTENTRVENDA AS DTREDUCAOZ
                FROM VENDA V
                JOIN (SELECT FILIOPERLOJACAIX.CDCAIXA, FILIOPERLOJACAIX.NMCAIXA, FILIOPERLOJACAIX.CDFILIAL, FILIOPERLOJACAIX.CDLOJA, FILIOPERLOJACAIX.NMLOJA, FILIOPERLOJACAIX.NRORG, T.DTFECHCAIX, T.DTMOVTURCAIX
                      FROM TURCAIXA T
                        JOIN (SELECT C.CDCAIXA, C.NMCAIXA, FILIOPERLOJA.CDFILIAL, FILIOPERLOJA.CDLOJA, FILIOPERLOJA.NMLOJA, FILIOPERLOJA.NRORG
                                FROM CAIXA C
                                JOIN (SELECT L.CDLOJA, L.NMLOJA, FILIOPER.CDFILIAL, L.NRORG
                                        FROM LOJA L
                                        JOIN (".$this->filialoperador.")FILIOPER
                                          ON FILIOPER.CDFILIAL = L.CDFILIAL
                                     )FILIOPERLOJA
                                  ON FILIOPERLOJA.CDFILIAL = C.CDFILIAL
                                 AND FILIOPERLOJA.CDLOJA = C.CDLOJA
                                 AND FILIOPERLOJA.NRORG = C.NRORG 
                             )FILIOPERLOJACAIX
                          ON FILIOPERLOJACAIX.CDCAIXA = T.CDCAIXA
                         AND FILIOPERLOJACAIX.CDFILIAL = T.CDFILIAL
                         AND FILIOPERLOJACAIX.NRORG = T.NRORG
                         AND T.DTFECHCAIX IS NOT NULL
                     )FILIOPERLOJACAIXTUR
                  ON FILIOPERLOJACAIXTUR.CDFILIAL = V.CDFILIAL
                 AND FILIOPERLOJACAIXTUR.CDLOJA = V.CDLOJA
                 AND FILIOPERLOJACAIXTUR.CDCAIXA = V.CDCAIXA
                 AND FILIOPERLOJACAIXTUR.NRORG = V.NRORG
                 AND FILIOPERLOJACAIXTUR.DTMOVTURCAIX = V.DTENTRVENDA
               WHERE V.IDTPEMISVEND IN ('N','S')
                 AND ( V.DTENTRVENDA BETWEEN NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY') - 30), SYSDATE-30) AND NVL(TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY'), SYSDATE))
                 AND ( INSTR('P_E', V.IDAPROVACAONFCE) > 0 )
                 AND V.IDTPAMBNFCE  = '1'
                 AND V.IDSTATUSNFCE = 'A')";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	public function getConsolidacaoVendaPendente ($params) {
		
		$query = "SELECT COUNT(TOT.NRNOTAFISCALCE) AS VENDASNAOCONSOLIDADAS
		  FROM (SELECT DISTINCT V.CDFILIAL, V.CDLOJA, FILIOPERLOJACAIX.NMLOJA, V.CDCAIXA, FILIOPERLOJACAIX.NMCAIXA, 
             		   NVL(V.NRCUPOMFIS, V.NRNOTAFISCALCE) AS NRNOTAFISCALCE
		  		  FROM VENDA V
		  		  JOIN (SELECT C.CDCAIXA, C.NMCAIXA, FILIOPERLOJA.CDFILIAL, FILIOPERLOJA.CDLOJA, FILIOPERLOJA.NMLOJA, FILIOPERLOJA.NRORG
				   		  FROM CAIXA C
				  		  JOIN (SELECT L.CDLOJA, L.NMLOJA, FILIOPER.CDFILIAL, L.NRORG
				  		  		  FROM LOJA L
						  		  JOIN (".$this->filialoperador.")FILIOPER
						     		ON FILIOPER.CDFILIAL = L.CDFILIAL
					   		   )FILIOPERLOJA
				    		ON FILIOPERLOJA.CDFILIAL = C.CDFILIAL
				   		   AND FILIOPERLOJA.CDLOJA = C.CDLOJA
				   		   AND FILIOPERLOJA.NRORG = C.NRORG
			   		   )FILIOPERLOJACAIX
					ON FILIOPERLOJACAIX.CDFILIAL = V.CDFILIAL
		   		   AND FILIOPERLOJACAIX.CDCAIXA = V.CDCAIXA
		   		   AND FILIOPERLOJACAIX.CDLOJA = V.CDLOJA
		   		   AND FILIOPERLOJACAIX.NRORG = V.NRORG
		  		  JOIN ITEMVENDA I
					ON V.CDFILIAL = I.CDFILIAL
		   		   AND V.CDCAIXA = I.CDCAIXA
		   		   AND V.NRSEQVENDA = I.NRSEQVENDA
		   		   AND V.NRORG = I.NRORG
		 		 WHERE V.NRORG = :NRORG
		   		   AND V.DTENTRVENDA BETWEEN NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY') -30),SYSDATE-30) AND NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY')),SYSDATE)
		   		   AND V.IDSITUVENDA IN ('O','D')
		   		   AND I.CDFILIALEST IS NULL
		   		   AND I.NRLANCESTQ IS NULL
		   	   ) TOT";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	public function getFechamentoCaixaPendente ($params) {
		
		$query = " SELECT COUNT(DTMOVTURCAIX) AS FECHCAIXPEND
          FROM TURCAIXA T
          JOIN (".$this->filialoperador.") F ON (F.CDFILIAL = T.CDFILIAL)
         WHERE T.DTFECHCAIX IS NULL  
           AND (T.DTMOVTURCAIX BETWEEN NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY') -30),SYSDATE-30) AND NVL((TO_DATE(:DTVNDCARDS, 'DD/MM/YYYY') -1),SYSDATE-1))";
		
		return $this->entityManager->getConnection()->fetchAssoc($query, $params);
	}
	
	
	//graphs
	
	private function getMensalGrafico(){
		$arrayBase = [];
		$meses = ['JAN', 'FEV', 'MAR', 'ABR', 'MAI', 'JUN', 'JUL', 'AGO', 'SET', 'OUT', 'NOV', 'DEZ'];
		foreach($meses as $key => $value){
			$key = $key + 1;
			if($key < 10){
				$ordem = "0".$key;
			}else{
				$ordem = $key;
			}
			
			$arrayBase[$key] = array(
					"QTVEND" => 0,
				    "TOTVENDA" => 0,
				    "TCKMEDIO" => 0,
				    "MES" => $value,
				    "ANO" => 0,
				    "QTVEND2" => 0,
				    "TOTVENDA2" => 0,
				    "TCKMEDIO2" => 0,
				    "MES2" => $value,
				    "VRMETA" => 0,
				    "ORDEM" => $ordem
				);
		}
		return $arrayBase;
	}
	
	//Graficos Corporativo
	
	private function getSaleGraph($params){
		
		$query = "SELECT TO_NUMBER(COUNT(V.NRSEQVENDA)) AS QTVEND, TO_NUMBER(SUM(NVL(V.VRTOTVENDA,0))) AS TOTVENDA, TO_NUMBER(TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2)) AS TCKMEDIO, 
			   TO_CHAR(V.DTENTRVENDA, 'MON') AS MES, TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
		  FROM VENDA V
		  JOIN (".$this->filialoperador.") F
		    ON V.CDFILIAL = F.CDFILIAL
        	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                    	    FROM METAMES M
                            JOIN (".$this->filialoperador.") F
                    		  ON M.CDFILIAL = F.CDFILIAL
                           WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
	                       GROUP BY M.CDANO, M.CDMES
                 		) M
        			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
        			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
			      WHERE V.IDSITUVENDA = 'O' 
					AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
                    AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
				  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
				  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')";
		
		return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	private function getSaleGraphLastYear($params){
		
		$query = "SELECT NVL(COUNT(V.NRSEQVENDA),0) AS QTVEND2, NVL(SUM(NVL(V.VRTOTVENDA,0)),0) AS TOTVENDA2, TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2) AS TCKMEDIO2, TO_CHAR(V.DTENTRVENDA, 'MON') AS MES2, 
        		TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO2, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
    	   FROM VENDA V
    	   JOIN (".$this->filialoperador.") F
    		 ON V.CDFILIAL = F.CDFILIAL
    	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                	    FROM METAMES M
                        JOIN (".$this->filialoperador.") F
                		  ON M.CDFILIAL = F.CDFILIAL
                       WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
                       GROUP BY M.CDANO, M.CDMES
             		) M
    			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
    			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
    	  WHERE V.IDSITUVENDA = 'O' 
    		AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
    		AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')-1
    	  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
		  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')";
		
		return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findSaleGraph ($condition) {
		$result = null; 
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
        $return = $this->getSaleGraph($params);
        $returnLY = $this->getSaleGraphLastYear($params);
        
        $arrayBase = $this->getMensalGrafico();
        
        foreach ($arrayBase as $key => $values) {
			foreach ($return as $key2 => $values2) {
				if($arrayBase[$key]['ORDEM'] == $values2['ORDEM']){
		        	$arrayBase[$key]['ORDEM'] = (float)$values2['ORDEM'];
		        	$arrayBase[$key]['QTVEND'] = (float)$values2['QTVEND'];
		        	$arrayBase[$key]['TCKMEDIO'] = (float)$values2['TCKMEDIO'];
		        	$arrayBase[$key]['TOTVENDA'] = (float)$values2['TOTVENDA'];
		        	$arrayBase[$key]['VRMETA'] = (float)$values2['VRMETA'];
				}
			}	
			foreach ($returnLY as $keyLY => $valuesLY) {
				if($arrayBase[$key]['ORDEM'] == $valuesLY['ORDEM']){
		        	$arrayBase[$key]['ORDEM'] = (float)$valuesLY['ORDEM'];
		        	$arrayBase[$key]['QTVEND2'] = (float)$valuesLY['QTVEND2'];
		        	$arrayBase[$key]['TCKMEDIO2'] = (float)$valuesLY['TCKMEDIO2'];
		        	$arrayBase[$key]['TOTVENDA2'] = (float)$valuesLY['TOTVENDA2'];
		        	$arrayBase[$key]['VRMETA'] = (float)$valuesLY['VRMETA'];
				}
			}
        }
        return $arrayBase;
	}
	
	public function findSaleTypeGraph ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT TOTAL, MODALIDADE, SUM (TOTVENDA) AS TOTVENDA, SUM(PERCENT) AS PERCENT
		  FROM (SELECT (SUM(TOTVENDA) OVER ( PARTITION BY BASE )) AS TOTAL, MODALIDADE, TOTVENDA, ROUND(((TOTVENDA/(SUM(TOTVENDA) OVER (PARTITION BY BASE)))* 100), 2) AS PERCENT 
		        FROM ( SELECT SUM (NVL(V.VRTOTVENDA,1)) AS TOTVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
		                      WHEN 'DLV' THEN 'DELIVERY'
		                      WHEN 'MES' THEN 'MESA'
		                      WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
		                      WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
		                      WHEN 'CMD' THEN 'COMANDA'
		                      WHEN 'AJU' THEN 'OUTROS' ELSE 'OUTROS'
		                      END AS MODALIDADE, 1 AS BASE
		                 FROM VENDA V
		                 JOIN (".$this->filialoperador.") F
		                   ON V.CDFILIAL = F.CDFILIAL
		                WHERE V.IDSITUVENDA = 'O' 
		                  AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
		                  AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
		                GROUP BY SUBSTR(V.IDORIGEMVENDA, 0, 3), SUBSTR(V.IDORIGEMVENDA, 5, 7)
		                ORDER BY SUBSTR(V.IDORIGEMVENDA, 0, 3)
		              )) 
		GROUP BY TOTAL, MODALIDADE";
		
        $return = $this->entityManager->getConnection()->fetchAll($query, $params);
        foreach ($return as &$values) {
        	$values['TOTAL'] = (float)$values['TOTAL'];
        	$values['TOTVENDA'] = (float)$values['TOTVENDA'];
        	$values['PERCENT'] = (float)$values['PERCENT'];
        }
        return $return;
	}
	
	public function findSalePaymentGraph ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT SUM(VR) AS TOT, CDTIPORECE, NMTIPORECE
		FROM (SELECT SUM(M.VRMOVIVEND) VR, M.CDTIPORECE, T.NMTIPORECE
			    FROM MOVCAIXA M
			    JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (".$this->filialoperador.") F
			      ON M.CDFILIAL = F.CDFILIAL
			   WHERE M.IDTIPOMOVIVE = 'E'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE
		   
		       UNION ALL
		   
			  SELECT (SUM(M.VRMOVIVEND))*-1 VR,  M.CDTIPORECE, T.NMTIPORECE
				FROM MOVCAIXA M
				JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (".$this->filialoperador.") F
			      ON M.CDFILIAL = F.CDFILIAL
			   WHERE M.IDTIPOMOVIVE = 'S'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE)
		 GROUP BY CDTIPORECE, NMTIPORECE
		 ORDER BY 1 DESC";
		
        $return = $this->entityManager->getConnection()->fetchAll($query, $params);
        foreach ($return as &$values) {
        	$values['TOT'] = (float)$values['TOT'];
        }
        return $return;
	}
	
	public function findSaleForDayGraph ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT A.CDFILIAL||' - '||B.NMFILIAL AS LABELFILIAL, A.DTENTRVENDA, A.TOTVENDA, ROUND(( (A.TOTVENDA /(SUM(A.TOTVENDA) OVER (PARTITION BY A.NRORG)))*100), 2)||'%' AS PERC
		 FROM (SELECT F.CDFILIAL, V.DTENTRVENDA, SUM(V.VRTOTVENDA) AS TOTVENDA, V.NRORG
			     FROM VENDA V
			     JOIN (".$this->filialoperador.") F
			       ON V.CDFILIAL = F.CDFILIAL
			    WHERE V.DTENTRVENDA = :DTENTRVENDA
			    GROUP BY F.CDFILIAL, V.DTENTRVENDA, V.NRORG) A, FILIAL B
			    WHERE A.CDFILIAL = B.CDFILIAL
		ORDER BY 1";
		
		
        $return = $this->entityManager->getConnection()->fetchAll($query, $params);;
        foreach ($return as &$values) {
        	$values['TOTVENDA'] = (float)$values['TOTVENDA'];
        	$values['PERC'] = (float)$values['PERC'];
        }
        
        return $return;
	}
	
	//Graficos Padrao
	
	public function findSaleGraphPorFilial ($condition) {
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':HORA' => date('G'),
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		if($params[':DATA'] != date('d/m/Y')){
			$params[':HORA'] = 23;
		}
		
		$query = "SELECT *
	    FROM (SELECT F.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,
					 F.CDFILIAL AS CDFILIAL, TRUNC(NVL(V.VRTOTAL, 0), 2) AS TOTALVEND, NVL(VRMETAHORAACUM, 0) AS META
				FROM VENDADIATOTAL V
			    JOIN FILIAL F
			      ON V.CDFILIAL   = F.CDFILIAL
	    		LEFT JOIN METAHORAREAL MHR
	    		  ON V.CDFILIAL = MHR.CDFILIAL
	    		 AND MHR.HORA = TO_NUMBER(:HORA)
				 AND TRUNC(MHR.DATA) = TO_DATE(:DATA, 'dd/mm/yy')
			   WHERE TRUNC(DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
				 AND V.CDFILIAL IN (".$this->filialoperador.")
			AND V.NRORG = :NRORG
			ORDER BY 3 DESC
			)
		WHERE ROWNUM <= ".self::MAX_FILTRO."";
		
		
		$returnDadosGetPorFilial = $this->entityManager->getConnection()->fetchAll($query, $params);
		
		
		if(empty($returnDadosGetPorFilial)){
			$filial = substr($condition['CDFILIAL'],0,4);
			$returnDadosGetPorFilial[0]['NOME'] = $this->findGetFilial($filial);
			$returnDadosGetPorFilial[0]['LABELFILIAL']  = $this->findGetFilial($filial);
			$returnDadosGetPorFilial[0]['TOTALVEND']  = 0;
			$returnDadosGetPorFilial[0]['META']  = 0;
			$returnDadosGetPorFilial[0]['CDFILIAL']  = $filial;
			$returnDadosGetPorFilial[0]['VAZIO']  = true;
		}
		
		if(!empty($returnDadosGetPorFilial)){
			foreach($returnDadosGetPorFilial as $key => $qry) {
					$totalVendido = $qry['TOTALVEND'];
	    			$meta = $qry['META'];
	
	    			if($meta > 0)
	    				$valorMeta = $meta - $totalVendido;
	    			else
	    				$valorMeta = 0;
	
	    			if ($valorMeta < 0)
	    				$valorMeta = 0;
	
	    			$qry['DADOSMETA'] = array (
	    				array(
	    					'LABELFILIAL' => "Total Vendido",
	    					'TOTALVEND'   => $totalVendido,
	    					'META'        => $meta,
	    					'ORDER'       => "0"),
	    				array(
	    					'LABELFILIAL' => "Diferença Meta Acumulada",
	    					'TOTALVEND'   => $valorMeta,
	    					'ORDER'       => "1")
	    			);
	    			$returnDadosGetPorFilial[$key]['DADOSMETA'] = $qry['DADOSMETA'];
	    	}
		}
		
        return $returnDadosGetPorFilial;
        
	}
	
	public function getTotalVenda ($condition) {
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT    '".self::NOME_TODAS_UNIDADES."' AS LABELFILIAL,
          TRUNC(NVL(SUM(NVL(V.VRTOTAL, 0)), 0), 2) AS TOTALVEND,
		  0.0                  AS META
		FROM VENDADIATOTAL V
		WHERE TRUNC(DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
		AND V.CDFILIAL IN
		  (".$this->filialoperador.")
		AND V.NRORG = :NRORG";
		
		
		return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function getVendaHora ($condition, $vazio) {

		$retornoArray = array();
		$unidades = array();
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
			
		$data = $params[':DATA'];
		
		$this->setFiliOper($condition, $params);
	
		$horaAtual = 23;
		
		
		$queryGeral = "SELECT * FROM (
		SELECT X.CDFILIAL        AS CDFILIAL,
		  X.NMFILIAL             AS NMFILIAL,
		  X.DATAVENDA            AS DATAVENDA,
    	  X.HORA                 AS HORA,
		  TRUNC(NVL(SUM(X.VRTOTAL), 0), 2) AS TOTALVEND,
		  X.META                 AS META
		FROM
		  (SELECT F.CDFILIAL,
		    NVL(VH.VRTOTALACUMULADO, 0) AS VRTOTAL,
		    NVL(TO_CHAR(VH.DTVENDA, 'dd/mm/yy'), :DATA) DATAVENDA,
		    NVL(VRMETAHORAACUM, 0) AS META,
            NVL(MHR.HORA, :HORA) AS HORA,
		    FILI.NMFILIAL
		  FROM (".$this->filialoperador.") F
		  LEFT JOIN VENDAHORATOTAL VH
		  ON F.CDFILIAL = VH.CDFILIAL
		  AND TRUNC(VH.DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
		  AND VH.HORAVENDA = :HORA
		  LEFT JOIN METAHORAREAL MHR
		  ON F.CDFILIAL = MHR.CDFILIAL
		  AND MHR.HORA = :HORA
          AND TRUNC(MHR.DATA) = TO_DATE(:DATA, 'dd/mm/yy')
		  JOIN FILIAL FILI
		  ON F.CDFILIAL   = FILI.CDFILIAL) X
		WHERE X.VRTOTAL > 0
		GROUP BY X.CDFILIAL, X.DATAVENDA, X.HORA, X.NMFILIAL, X.DATAVENDA, X.META
		ORDER BY 5 DESC
	  )
	  WHERE ROWNUM <= ".self::MAX_FILTRO."";
	  
	  for ($i = 0; $i <= $horaAtual+1; $i++) {

			$params[':HORA'] =  $i;
			
			$query = $this->entityManager->getConnection()->fetchAll($queryGeral, $params);
			
			if(empty($query) && !($vazio)){
				$query[0]['NMFILIAL']  = substr($this->findGetFilial($condition['CDFILIALLOG']), 7);
				$query[0]['TOTALVEND']  = 0;
				$query[0]['META']  = 0;
				$query[0]['HORA']  = 0;
				$query[0]['CDFILIAL']  = $condition['CDFILIALLOG'];
				$query[0]['DATAVENDA']  = $condition['DTVNDCARDS'];
			}
			
			$j = 0;
			$total = 0;

			foreach($query as $resultado) {

				$arrayVendas = array();

				$total = $query[$j]['TOTALVEND'];
				$data = $query[$j]['DATAVENDA'];
				$cdfilial = $query[$j]['CDFILIAL'];
				$nmfilial = $query[$j]['NMFILIAL'];
				$meta = $query[$j]['META'];

				$unidade = $this->getObjeto($unidades, $cdfilial, $nmfilial);
				$unidade->addVendas($i.":00", $total, $meta);
	            $j++;

			}
        }

        if($data != date('d/m/y')) {
			$horaAtual = "23:00";
		} else
	    	$horaAtual = date('G').":00";
        foreach($unidades as $unidade) {
        	$retornoArray[] = array(
        		"LABELFILIAL"     => $unidade->getLabelFilial(),
        		"VENDAS"		  => $unidade->getVendas($horaAtual)
        	);
        }
        
		return $retornoArray;
	}

	public function getObjeto (array & $array, $cdfilial, $nmfilial) {

		$objUnidade;
		$i = 0;

		foreach($array as $unidade) {
			if($unidade->getCdFilial() == $cdfilial) {
				$objUnidade = $unidade;
				break;
			}
		}

		if(empty($objUnidade)) {
			$objUnidade = new ObjetoUnidade($cdfilial, $nmfilial);
			$array[] = $objUnidade;
		}

		return $objUnidade;

	}
	
	public function getTicketMedio ($condition) {
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT    '".self::NOME_TODAS_UNIDADES."' AS LABELFILIAL,
          TRUNC(NVL(AVG(NVL(V.VRTICKETMED, 0)), 0),2 ) AS TICKETMEDIO,
		  0.0                  AS META
		FROM VENDADIATOTAL V
		WHERE TRUNC(DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
		AND V.CDFILIAL IN
		  (".$this->filialoperador.")
		AND V.NRORG = :NRORG";
		
		
		return $this->entityManager->getConnection()->fetchAll($query, $params);
	}

	public function getTicketMedioFilial ($condition) {
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT *
		  FROM (
				 SELECT F.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL, TRUNC(NVL(V.VRTICKETMED, 0), 2) AS TICKETMEDIO, NVL(MDR.VRTCKMED,0)   AS META
				   FROM VENDADIATOTAL V
				   JOIN FILIAL F
					 ON V.CDFILIAL   = F.CDFILIAL
				   LEFT JOIN METADIAREAL MDR
					 ON F.CDFILIAL = MDR.CDFILIAL
					AND TRUNC(MDR.DATA) = TO_DATE(:DATA, 'dd/mm/yy')
				  WHERE TRUNC(DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
					AND V.CDFILIAL IN (".$this->filialoperador.")
					AND V.NRORG = :NRORG
				  ORDER BY 2 DESC
				 )
		WHERE ROWNUM <= ".self::MAX_FILTRO."";
		
		$dadosRetorno = $this->entityManager->getConnection()->fetchAll($query, $params);
		
		if(empty($dadosRetorno)){
			$dadosRetorno[0]['LABELFILIAL']  = $this->findGetFilial($condition['CDFILIALLOG']);
			$dadosRetorno[0]['TICKETMEDIO']  = 0;
			$dadosRetorno[0]['META']  = 0;
		}
		
		return $dadosRetorno;
		
	}
	
	public function getVendaModalidade ($condition) {
		$retorno = array();
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		$query = "SELECT
                MODALIDADE,
                TRUNC(NVL(SUM(VENDAS), 0), 2)   AS TOTALVEND,
                '".self::NOME_TODAS_UNIDADES."' AS LABELFILIAL
            FROM
                (
                    SELECT
                      CASE IDMODALIDADE WHEN 'DLV' THEN 'Delivery' 
                      WHEN 'MES' THEN 'Mesa' 
                      WHEN 'BAL' THEN 'Balcão'
                      WHEN 'CMD' THEN 'Comanda' 
                       WHEN 'TAA' THEN 'TAA'
                      ELSE 'Outros' END AS MODALIDADE,
                        NVL(VRTOTAL, 0) AS VENDAS
                    FROM
                        VENDADIAMODALIDADE
                    WHERE
                            TRUNC(DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
                        AND CDFILIAL IN (".$this->filialoperador.")
                        AND NRORG = :NRORG
                ) X
            GROUP BY
                MODALIDADE";
		
		$modalidades = ["Mesa", "Balcão", "Delivery", "TAA", "Comanda", "Outros"];
		$resultado = $this->entityManager->getConnection()->fetchAll($query, $params);
		
		if(empty($resultado)){
			foreach ($modalidades as $key => $values) {
				$resultado[$key]['LABELFILIAL'] = "Todas Unidades";
				$resultado[$key]['MODALIDADE'] = $values;
				$resultado[$key]['TOTALVEND'] = 0;
			}
		}
		
		return $resultado;
	}

	public function getVendaModalidadeFilial ($condition) {
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIALP'],
			':TCDFILIAL'	=> $condition['TCDFILIALP'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DATA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT * FROM (
                SELECT X.CDFILIAL,
                  X.LABELFILIAL,
                  X.MODALIDADE,
                  TRUNC(X.VENDAS, 2) AS TOTALVEND,
                  NVL(MM.VRMETADIA, 0) AS META,
                NVL(MMD.VRMETAMODALIDADE, 0) AS METAMODALIDADE
                  FROM (SELECT
                        VDM.CDFILIAL,
                        F.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,
                        CASE SUBSTR(IDMODALIDADE, 5, 3) WHEN 'AUT' THEN 'TAA'
                                    WHEN 'TAA' THEN 'TAA'
                                    ELSE (CASE IDMODALIDADE WHEN 'DLV' THEN 'Delivery' 
                                                                          WHEN 'MES' THEN 'Mesa' 
                                                                          WHEN 'BAL' THEN 'Balcão'
                                                                          WHEN 'CMD' THEN 'Comanda' 
                                                                           WHEN 'TAA' THEN 'TAA'
                                                                          ELSE 'Outros' END )END AS MODALIDADE,
                        NVL(VRTOTAL, 0) AS VENDAS
                      FROM VENDADIAMODALIDADE VDM
                      JOIN FILIAL F
                      ON F.CDFILIAL = VDM.CDFILIAL
                      WHERE TRUNC(VDM.DTVENDA) = TO_DATE(:DATA, 'dd/mm/yy')
                      AND VDM.CDFILIAL IN
                        (".$this->filialoperador.")
                      AND INSTR('MES_BAL_DLV_TAA_CMD_VND_OUT', SUBSTR(VDM.IDMODALIDADE, 0, 3)) > 0
                      AND VDM.NRORG = :NRORG
                      ORDER BY CDFILIAL) X
                  LEFT JOIN METADIAREAL MM
                    ON X.CDFILIAL = MM.CDFILIAL
                    AND TRUNC(MM.DATA) = TO_DATE(:DATA, 'dd/mm/yy')
                LEFT JOIN METAMODALIDADEREAL MMD
                    ON X.CDFILIAL = MMD.CDFILIAL
                AND MMD.IDMODALIDADE = X.MODALIDADE
                    AND TRUNC(MMD.DATA) = TO_DATE(:DATA, 'dd/mm/yy')
                  ORDER BY 4 DESC
                  )
                  WHERE ROWNUM <= 10";
		
		$resultado = $this->entityManager->getConnection()->fetchAll($query, $params);
		
		if(empty($resultado))
			$resultado = array(
				array(
					"UNIDADE" => "Todas Unidades",
					"MES"     => 0,
					"BAL"	  => 0,
					"TAA"     => 0,
					"CMD"     => 0,
					"OUTROS"  => 0)
				);
				
		foreach ($resultado as $key => $values) {
             if(isset($resultado[$key]['TOTALVEND'])){
                 $resultado[$key]['TOTALVEND'] = (float)$resultado[$key]['TOTALVEND'];
             }
         }
		return $resultado;
	}
	
	//Tabelas 
	
	public function findProdutoMaiorCusto ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT P.CDARVPROD, P.NMPRODUTO, FN.VRCUSTO FROM (SELECT B.CDPRODUTO, ROUND(B.VRCUSTO,3) AS VRCUSTO
		  FROM (SELECT A.CDPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, B.CDPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B		                       
		                       JOIN  (".$this->filialoperador.") F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDPRODUTO
		 ORDER BY 2 DESC) B
		WHERE ROWNUM <= 10) FN
        JOIN PRODUTO P ON (P.CDPRODUTO = FN.CDPRODUTO)";
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findProdutoMenorCusto ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT P.CDARVPROD, P.NMPRODUTO, FN.VRCUSTO FROM (SELECT B.CDPRODUTO, ROUND(B.VRCUSTO,3) AS VRCUSTO
		  FROM (SELECT A.CDPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, B.CDPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B		                       
		                       JOIN  (".$this->filialoperador.") F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDPRODUTO
		 ORDER BY 2) B
		WHERE ROWNUM <= 10) FN
        JOIN PRODUTO P ON (P.CDPRODUTO = FN.CDPRODUTO)";
        
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findProdMaisAjustes ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT A.CDARVPROD, A.NMPRODUTO, A.SGUNIDADE, A.QTDEAJUSTE
		  FROM (SELECT P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE, COUNT(*) AS QTDEAJUSTE
		          FROM ITLANCTOEST I
		          JOIN PRODUTO P
		            ON P.CDPRODUTO = I.CDPRODMOVI
		          JOIN  (".$this->filialoperador.") F
		            ON I.CDFILIMOVI = F.CDFILIAL
		         WHERE I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
		           AND I.IDTIPOMOVI = '1'
		           AND I.IDEVOLESTOQ = 'S'
		         GROUP BY P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE
		         ORDER BY 4 DESC, P.CDARVPROD) A
		 WHERE ROWNUM <= 10";
		
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findUnidadeSemContagem ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT 'Unidades sem realizar Contagem nos últimos 7 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM  (".$this->filialoperador.") F
		 WHERE NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 7 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 15 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM  (".$this->filialoperador.") F
		 WHERE NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 15 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 30 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM  (".$this->filialoperador.") F
		 WHERE NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 30 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')";
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findUltimaContagem ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS']
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_ULTIMO_AJUSTE, $params);
	}
	
	public function findContasPagar ($condition) {
		$result = null; 
		$array = [];
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J, (".$this->filialoperador.") F, FILIAL FL
		WHERE F.CDFILIAL = FL.CDFILIAL
		AND J.CDEMPRESA = FL.CDEMPRESA
		AND J.IDINFJOB = 'P'
		GROUP BY J.CDEMPRESA";
		
        $result = $this->entityManager->getConnection()->fetchAll($query, $params);
        foreach ($result as $value) {
        	$array = array(
				[
					'LABELVALIDADE' => 'Pagar Hoje',
					'VALOR' => $value['VRVENCDIA']
				],
				[
					'LABELVALIDADE' => 'Vencidos',
					'VALOR' => $value['VRTOTALVENCIDO']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 7 Dias',
					'VALOR' => $value['VRVENC7DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 15 Dias',
					'VALOR' => $value['VRVENC15DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 30 Dias',
					'VALOR' => $value['VRVENC30DIAS']
				]
			);
        }
        return $array;
	}
	
	public function findContasReceber ($condition) {
		$result = null; 
		$array = [];
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J, (".$this->filialoperador.") F, FILIAL FL
		WHERE F.CDFILIAL = FL.CDFILIAL
		AND J.CDEMPRESA = FL.CDEMPRESA
		AND J.IDINFJOB = 'R'
		GROUP BY J.CDEMPRESA";
		
        $result = $this->entityManager->getConnection()->fetchAll($query, $params);
        foreach ($result as $value) {
        	$array = array(
				[
					'LABELVALIDADE' => 'Pagar Hoje',
					'VALOR' => $value['VRVENCDIA']
				],
				[
					'LABELVALIDADE' => 'Vencidos',
					'VALOR' => $value['VRTOTALVENCIDO']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 7 Dias',
					'VALOR' => $value['VRVENC7DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 15 Dias',
					'VALOR' => $value['VRVENC15DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 30 Dias',
					'VALOR' => $value['VRVENC30DIAS']
				]
			);
        }
        return $array;
	}
	
	public function findSaldoEmContas ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT SUM(J.VRSALDOCCOR) AS VRSALDO, J.CDEMPRESA, J.DSBANCO AS DESCRICAO
		  FROM JOB_FINAN J, (".$this->filialoperador.") F, FILIAL FL
			WHERE F.CDFILIAL = FL.CDFILIAL
			AND J.CDEMPRESA = FL.CDEMPRESA
		    AND  J.IDINFJOB = 'S'
		GROUP BY J.CDEMPRESA, J.DSBANCO";
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findStatusNotaTab ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT 'NF entrada Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
    	UNION ALL
        
        SELECT 'NF entrada em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
	    UNION ALL
        
        SELECT 'NF Saida em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN  (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    	
    	UNION ALL   
           
        SELECT 'NF Saida Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN (".$this->filialoperador.") F
		    ON N.CDFILIAL = F.CDFILIAL
	     WHERE N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA";
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	public function findCMVTab ($condition) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $condition['CDFILIAL'],
			':TCDFILIAL'	=> $condition['TCDFILIAL'],
			':NRORG'		=> $condition['NRORG'],
			':CDOPERADOR'	=> $condition['CDOPERADOR'],
			':DTENTRVENDA'	=> $condition['DTVNDCARDS'],
			':PERFIL'	=> $condition['CDPERFILSELECIONADO']
		);
		
		$this->setFiliOper($condition, $params);
		
		$query = "SELECT V.CDFILIAL||' - '||FI.NMFILIAL AS LABELFILIAL, ROUND(NVL(CMVDASHIDEAL, 0 ),2) AS CMVDASHIDEAL, 
			   ROUND(NVL(CMVDASHREDE, 0 ),2) AS CMVDASHREDE, ROUND(NVL(CMVDASHREAL, 0 ),2) AS CMVDASHREAL
		  FROM VNDCARDS V
		  JOIN FILIAL FI
		    ON V.CDFILIAL = FI.CDFILIAL
		    AND V.NRORG = FI.NRORG
		  JOIN (".$this->filialoperador.") FO
		    ON V.CDFILIAL = FO.CDFILIAL
		   AND FI.CDFILIAL = FO.CDFILIAL
		 WHERE ((INSTR(:CDFILIAL , V.CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTENTRVENDA";
		
        return $this->entityManager->getConnection()->fetchAll($query, $params);
	}
	
	const GET_IS_FILIAL_BLOQ = "
		SELECT FILIAL.NMFILIAL,
		  FILIAL.NRORG,
		  FILIAL.IDSTATUSBLOQ
		FROM FILIAL
		INNER JOIN FILIOPER FI
		ON(FILIAL.CDFILIAL    = FI.CDFILIAL
		AND CDOPERADOR        = :CDOPERADOR
		AND FILIAL.NRORG      = FI.NRORG)
		WHERE FILIAL.NRORG    = :NRORG
		AND FILIAL.IDCNTRRESC = 'N'
		AND FILIAL.CDFILIAL = :CDFILIAL
		AND FILIAL.IDSTATUSBLOQ = 'S'
		ORDER BY FILIAL.CDFILIAL
	";
	
	const PERF_UTL_BLOQ = "
	SELECT IDBLOCKFILIAL 
		FROM PERFILACESSO 
		WHERE NRPERFILACESSO = :NRPERFILACESSO
			AND NRORG = :NRORG";
	
	const GET_PARAM_OPERADOR = "
	SELECT
	    O.CDPERFILSELECIONADO AS CDPERFILACESSO,
	    PF.NMPERFILACESSO,
	    O.CDOPERADOR
	FROM
	    OPERADOR       O
	    JOIN PERFILACESSO   PF 
	    	ON PF.NRPERFILACESSO = O.CDPERFILSELECIONADO
	WHERE
	    O.CDOPERADOR = :CDOPERADOR AND
	    O.NRORG 	 = :NRORG";
	    
	const GET_PERFIL_OPERADOR = "
		SELECT CDPERFILSELECIONADO 
		  FROM OPERADOR 
		 WHERE CDOPERADOR = :CDOPERADOR 
		   AND NRORG = :NRORG
	";
	
	const GET_TYPE_DASHBOARD = "
		SELECT IDDASHBOARD 
		  FROM PARAMGERAL 
	";
	
	const GET_FILIAL = "
		SELECT (CDFILIAL || ' - ' || NMFILIAL) AS FILIAL
		  FROM FILIAL
		  WHERE CDFILIAL = :CDFILIAL
	";
	
	
	const GET_V_QTTICKET_ALL = "
		SELECT SUM(NVL(V.QTTICKETCARD, 0 )) QTTICKETCARD, SUM( NVL(V.TOTVENDCARD, 0 ) ) TOTVENDCARD,
			   SUM( NVL(V.CANCVENDCARD, 0 ) ) CANCVENDCARD, SUM( NVL(V.FECHCAIXPENDCARD, 0 ) ) FECHCAIXPENDCARD,
				SUM( NVL(V.APROVMOVCARD, 0 ) ) APROVMOVCARD, SUM( NVL(V.DIFAPURACARD, 0 ) ) DIFAPURACARD,
				SUM( NVL(V.QTDIFAPURACARD, 0 ) ) QTDIFAPURACARD, SUM( NVL(V.CUPOMPENDCARD, 0 ) ) CUPOMPENDCARD,
				SUM( NVL(V.ITESTPENDCARD, 0 ) ) ITESTPENDCARD, SUM( NVL(V.AVGTICKETCARD, 0)  )AVGTICKETCARD,
				SUM( NVL(V.PRODIRREG, 0)  ) PRODIRREG
		  FROM VNDCARDS V
		  JOIN FILIOPER F
		    ON V.CDFILIAL = F.CDFILIAL
		   AND V.NRORG = F.NRORG
		 WHERE V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTVNDCARDS 
           AND F.CDOPERADOR = :CDOPERADOR
	";
	
	//PEND -> PENDENTE
	//DIGIT -> EM DIGITAÇÃO
	//HAND -> MANUALMENTE
	
	// Notas fiscais de entrada Pendentes
	
	const GET_NFE_PEND = "
		SELECT COUNT(*) QTNFEPEND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
	       AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de entrada em digitação
	
	const GET_NFE_DIGIT = "
		SELECT COUNT(*) QTNFEDIGIT
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de saida Pendentes
	
	const GET_NFS_PEND = "
		SELECT COUNT(*) QTNFSPEND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de saida em digitação
	
	const GET_NFS_DIGIT = "
		SELECT COUNT(*) QTNFSDIGIT
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais importadas via XML
	
	const GET_NFE_IMPORT_XML = "
		SELECT COUNT(*) QTNFEIMPORTXML
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'S'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais digitadas manualmente
	
	const GET_NFE_DIGIT_HAND = "
		SELECT COUNT(*) QTNFEDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'N'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais digitadas manualmente
	
	const GET_NFS_DIGIT_HAND = "
		SELECT COUNT(*) QTNFSDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Graphics but not Graphql
	
	const GET_SALE_GRAPH = "
		SELECT TO_NUMBER(COUNT(V.NRSEQVENDA)) AS QTVEND, TO_NUMBER(SUM(NVL(V.VRTOTVENDA,0))) AS TOTVENDA, TO_NUMBER(TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2)) AS TCKMEDIO, 
			   TO_CHAR(V.DTENTRVENDA, 'MON') AS MES, TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
		  FROM VENDA V
		  JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		          FROM FILIOPER FO
		          JOIN (SELECT CDFILIAL, NRORG
		                  FROM FILIAL
		                 WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                   AND NRORG = :NRORG
		               ) F
		            ON FO.CDFILIAL = F.CDFILIAL
		           AND FO.NRORG = F.NRORG
		         WHERE FO.CDOPERADOR = :CDOPERADOR
		       ) F
		    ON V.CDFILIAL = F.CDFILIAL
		   AND V.NRORG = F.NRORG
        	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                    	    FROM METAMES M
                            JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
                                    FROM FILIOPER FO
                                    JOIN (SELECT CDFILIAL, NRORG
                                		    FROM FILIAL
                                    	   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                                    		 AND NRORG = :NRORG
                                		 ) F
                                	  ON FO.CDFILIAL = F.CDFILIAL
	                                 AND FO.NRORG = F.NRORG
                            	   WHERE FO.CDOPERADOR = :CDOPERADOR
	                             ) F
                    		  ON M.CDFILIAL = F.CDFILIAL
                           WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
	                       GROUP BY M.CDANO, M.CDMES
                 		) M
        			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
        			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
			      WHERE V.IDSITUVENDA = 'O' 
					AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
                    AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
				  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
				  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')
	";
	
	const GET_SALE_GRAPH_LAST_YEAR = "
		SELECT NVL(COUNT(V.NRSEQVENDA),0) AS QTVEND2, NVL(SUM(NVL(V.VRTOTVENDA,0)),0) AS TOTVENDA2, TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2) AS TCKMEDIO2, TO_CHAR(V.DTENTRVENDA, 'MON') AS MES2, 
        		TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO2, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
    	   FROM VENDA V
    	   JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
            	   FROM FILIOPER FO
            	   JOIN (SELECT CDFILIAL, NRORG
                		   FROM FILIAL
                    	  WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                    		AND NRORG = :NRORG
                		) F
            		 ON FO.CDFILIAL = F.CDFILIAL
            		AND FO.NRORG = F.NRORG
            	  WHERE FO.CDOPERADOR = :CDOPERADOR
        		) F
    		 ON V.CDFILIAL = F.CDFILIAL
    		AND V.NRORG = F.NRORG
    	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                	    FROM METAMES M
                        JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
                                FROM FILIOPER FO
                                JOIN (SELECT CDFILIAL, NRORG
                            		    FROM FILIAL
                                	   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                                		 AND NRORG = :NRORG
                            		 ) F
                            	  ON FO.CDFILIAL = F.CDFILIAL
                                 AND FO.NRORG = F.NRORG
                        	   WHERE FO.CDOPERADOR = :CDOPERADOR
                             ) F
                		  ON M.CDFILIAL = F.CDFILIAL
                       WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
                       GROUP BY M.CDANO, M.CDMES
             		) M
    			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
    			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
    	  WHERE V.IDSITUVENDA = 'O' 
    		AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
    		AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')-1
    	  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
		  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')
	";
	
	const GET_SALE_TYPE_GRAPH = "
		SELECT TOTAL, MODALIDADE, SUM (TOTVENDA) AS TOTVENDA, SUM(PERCENT) AS PERCENT
		  FROM (SELECT (SUM(TOTVENDA) OVER ( PARTITION BY BASE )) AS TOTAL, MODALIDADE, TOTVENDA, ROUND(((TOTVENDA/(SUM(TOTVENDA) OVER (PARTITION BY BASE)))* 100), 2) AS PERCENT 
		        FROM ( SELECT SUM (NVL(V.VRTOTVENDA,1)) AS TOTVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
		                      WHEN 'DLV' THEN 'DELIVERY'
		                      WHEN 'MES' THEN 'MESA'
		                      WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
		                      WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
		                      WHEN 'CMD' THEN 'COMANDA'
		                      WHEN 'AJU' THEN 'OUTROS' ELSE 'OUTROS'
		                      END AS MODALIDADE, 1 AS BASE
		                 FROM VENDA V
		                 JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                          FROM FILIOPER FO
		                          JOIN (SELECT CDFILIAL, NRORG
		                                  FROM FILIAL
		                                 WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                                   AND NRORG = :NRORG
		                               ) F
		                            ON FO.CDFILIAL = F.CDFILIAL
		                           AND FO.NRORG = F.NRORG
		                         WHERE FO.CDOPERADOR = :CDOPERADOR
		                      ) F
		                   ON V.CDFILIAL = F.CDFILIAL
		                  AND V.NRORG = F.NRORG
		                WHERE V.IDSITUVENDA = 'O' 
		                  AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
		                  AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
		                GROUP BY SUBSTR(V.IDORIGEMVENDA, 0, 3), SUBSTR(V.IDORIGEMVENDA, 5, 7)
		                ORDER BY SUBSTR(V.IDORIGEMVENDA, 0, 3)
		              )) 
		GROUP BY TOTAL, MODALIDADE
	";
	
	const GET_SALE_PAYMENT_FOR_DAY = "
	  SELECT SUM(VR) AS TOT, CDTIPORECE, NMTIPORECE
		FROM (SELECT SUM(M.VRMOVIVEND) VR, M.CDTIPORECE, T.NMTIPORECE
			    FROM MOVCAIXA M
			    JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
			            FROM FILIOPER FO
			            JOIN (SELECT CDFILIAL, NRORG
			                    FROM FILIAL
			                   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
			                     AND NRORG = :NRORG
			                 ) F
			              ON FO.CDFILIAL = F.CDFILIAL
			             AND FO.NRORG = F.NRORG
			           WHERE FO.CDOPERADOR = :CDOPERADOR
			         ) F
			      ON M.CDFILIAL = F.CDFILIAL
			     AND M.NRORG = F.NRORG 
			   WHERE M.IDTIPOMOVIVE = 'E'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE
		   
		       UNION ALL
		   
			  SELECT (SUM(M.VRMOVIVEND))*-1 VR,  M.CDTIPORECE, T.NMTIPORECE
				FROM MOVCAIXA M
				JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
			            FROM FILIOPER FO
			            JOIN (SELECT CDFILIAL, NRORG
			                    FROM FILIAL
			                   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
			                     AND NRORG = :NRORG
			                 ) F
			              ON FO.CDFILIAL = F.CDFILIAL
			             AND FO.NRORG = F.NRORG
			           WHERE FO.CDOPERADOR = :CDOPERADOR
			         ) F
			      ON M.CDFILIAL = F.CDFILIAL
			     AND M.NRORG = F.NRORG 
			   WHERE M.IDTIPOMOVIVE = 'S'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE)
		 GROUP BY CDTIPORECE, NMTIPORECE
		 ORDER BY 1 DESC
	";
	
	const GET_SALE_FOR_DAY = "
		SELECT A.CDFILIAL||' - '||A.NMFILIAL AS LABELFILIAL, A.NRORG, A.DTENTRVENDA, A.TOTVENDA, ROUND(( (A.TOTVENDA /(SUM(A.TOTVENDA) OVER (PARTITION BY A.NRORG)))*100), 2)||'%' AS PERC
		 FROM (SELECT F.CDFILIAL, F.NMFILIAL, F.NRORG, V.DTENTRVENDA, SUM(V.VRTOTVENDA) AS TOTVENDA
			     FROM VENDA V
			     JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.NMFILIAL
					     FROM FILIOPER FO
					     JOIN (SELECT CDFILIAL, NRORG, NMFILIAL
					             FROM FILIAL
					            WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
					              AND NRORG = :NRORG
					          ) F
					       ON FO.CDFILIAL = F.CDFILIAL
					      AND FO.NRORG = F.NRORG
					    WHERE FO.CDOPERADOR = :CDOPERADOR
					  ) F
			       ON V.CDFILIAL = F.CDFILIAL
			      AND V.NRORG = F.NRORG
			    WHERE V.DTENTRVENDA = :DTENTRVENDA
			    GROUP BY F.CDFILIAL, F.NMFILIAL, F.NRORG, V.DTENTRVENDA) A
		ORDER BY 1
	";
	
	// Tabelas Dashboard 
	
	const TAB_RNK_MENOR_CUSTO = "
		SELECT P.CDARVPROD, P.NMPRODUTO, FN.VRCUSTO FROM (SELECT B.CDPRODUTO, ROUND(B.VRCUSTO,10) AS VRCUSTO
		  FROM (SELECT A.CDPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, B.CDPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B		                       
		                       JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                               FROM FILIOPER FO
		                       JOIN (SELECT CDFILIAL, NRORG
		                               FROM FILIAL
		                              WHERE ((INSTR(:CDFILIAL, CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
		                                AND NRORG = :NRORG) F
		                          ON FO.CDFILIAL = F.CDFILIAL
		                         AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDPRODUTO
		 ORDER BY 2) B
		WHERE ROWNUM <= 10) FN
        JOIN PRODUTO P ON (P.CDPRODUTO = FN.CDPRODUTO)
	";
	
	const TAB_RNK_MAIOR_CUSTO = "
		SELECT P.CDARVPROD, P.NMPRODUTO, FN.VRCUSTO FROM (SELECT B.CDPRODUTO, ROUND(B.VRCUSTO,3) AS VRCUSTO
		  FROM (SELECT A.CDPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, B.CDPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B		                       
		                       JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                               FROM FILIOPER FO
		                       JOIN (SELECT CDFILIAL, NRORG
		                               FROM FILIAL
		                              WHERE ((INSTR(:CDFILIAL , CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
		                                AND NRORG = :NRORG) F
		                          ON FO.CDFILIAL = F.CDFILIAL
		                         AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDPRODUTO
		 ORDER BY 2 DESC) B
		WHERE ROWNUM <= 10) FN
        JOIN PRODUTO P ON (P.CDPRODUTO = FN.CDPRODUTO)
	";
	
	const TAB_UNIDADES_SEM_CONTAGEM = "
		SELECT 'Unidades sem realizar Contagem nos últimos 7 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 7 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 15 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 15 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 30 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 30 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')

	";
	
	const TAB_ULTIMO_AJUSTE = "
		SELECT 'Quantidade de ajustes: '||A.QTDEAJUSTE AS UM, 'Data: '||B.DTULTIMOINVE AS DOIS
		  FROM (SELECT COUNT(DISTINCT I.NRLANCESTQ) AS QTDEAJUSTE
	        	  FROM ITLANCTOEST I, PRODUTO P
	        	 WHERE ((INSTR(:CDFILIAL , I.CDFILIMOVI ) <> 0) OR (:TCDFILIAL = 'T'))
	               AND I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	               AND I.IDTIPOMOVI = '1'
	               AND I.IDEVOLESTOQ = 'S'
	               AND P.CDPRODUTO = I.CDPRODMOVI) A,
	           (SELECT MAX(I.DTLANCMOVI) AS DTULTIMOINVE
	              FROM ITLANCTOEST I, PRODUTO P
	             WHERE ((INSTR(:CDFILIAL , I.CDFILIMOVI ) <> 0) OR (:TCDFILIAL = 'T'))
	               AND I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	               AND I.IDTIPOMOVI = '1'
	               AND I.IDEVOLESTOQ = 'S'
	               AND P.CDPRODUTO = I.CDPRODMOVI) B
	";
	
	const TAB_PROD_MAIS_AJUSTES = "
		SELECT A.CDARVPROD, A.NMPRODUTO, A.SGUNIDADE, A.QTDEAJUSTE
		  FROM (SELECT P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE, COUNT(*) AS QTDEAJUSTE
		          FROM ITLANCTOEST I
		          JOIN PRODUTO P
		            ON P.CDPRODUTO = I.CDPRODMOVI
		          JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                  FROM FILIOPER FO
		                  JOIN (SELECT CDFILIAL, NRORG
		                          FROM FILIAL
		                         WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                           AND NRORG = :NRORG
		                       ) F
		                    ON FO.CDFILIAL = F.CDFILIAL
		                   AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F
		            ON I.CDFILIMOVI = F.CDFILIAL
		         WHERE I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
		           AND I.IDTIPOMOVI = '1'
		           AND I.IDEVOLESTOQ = 'S'
		         GROUP BY P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE
		         ORDER BY 4 DESC, P.CDARVPROD) A
		 WHERE ROWNUM <= 10
	";
	
	const  TAB_CONTAS_PAGAR = "
		SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'P'
		GROUP BY J.CDEMPRESA
	";
	
	const TAB_CONTAS_RECEBER = "
		SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'R'
		GROUP BY J.CDEMPRESA
	";
	
	const TAB_SALDO_EM_CONTA = "
		SELECT SUM(J.VRSALDOCCOR) AS VRSALDO, J.CDEMPRESA, J.DSBANCO AS DESCRICAO
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'S'
		GROUP BY J.CDEMPRESA, J.DSBANCO
	";
	
	const TAB_STATUS_NOTA = "
		SELECT 'NF entrada Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
	       AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
    	UNION ALL
        
        SELECT 'NF entrada em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
	    UNION ALL
        
        SELECT 'NF Saida em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    	
    	UNION ALL   
           
        SELECT 'NF Saida Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	";
	
	const TAB_CMV = "
		SELECT V.CDFILIAL||' - '||FI.NMFILIAL AS LABELFILIAL, ROUND(NVL(CMVDASHIDEAL, 0 ),2) AS CMVDASHIDEAL, 
			   ROUND(NVL(CMVDASHREDE, 0 ),2) AS CMVDASHREDE, ROUND(NVL(CMVDASHREAL, 0 ),2) AS CMVDASHREAL
		  FROM VNDCARDS V
		  JOIN FILIAL FI
		    ON V.CDFILIAL = FI.CDFILIAL
		    AND V.NRORG = FI.NRORG
		  JOIN FILIOPER FO
		    ON V.CDFILIAL = FO.CDFILIAL
		   AND V.NRORG = FO.NRORG
		   AND FI.CDFILIAL = FO.CDFILIAL
		 WHERE ((INSTR(:CDFILIAL , V.CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTENTRVENDA 
		   AND FO.CDOPERADOR = :CDOPERADOR
	";
	
	// Data vencimento certificado digital
	
	const GET_VALID_CERTIFICADO = "
		SELECT DISTINCT C.IDTPEMISSAOFOS AS EMISSAO
		  FROM CAIXA C
	     WHERE ((INSTR(:CDFILIAL , C.CDFILIAL ) <> 0))
	";

	
	const GET_VENCIMENTO_CERTIFICADO = "
		SELECT TRUNC(P.DTVALCERTDIGNFCE  - sysdate, 0 ) AS VENCIMENTO
		  FROM PARAVEND P
	     WHERE ((INSTR(:CDFILIAL , P.CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
	";
	
	
	//querys dashboard padrao
	
	const COUNT_DIVERGENCIAS_CONCILIACO = "
    SELECT COUNT(*) AS CNCCONCERROSCARD
      FROM LOGERROCTBCNC
     WHERE NRORG = :NRORG
    ";

} 
